@@ -1,14 +1,14 @@
 /*
  gc_computers.c - Functions for the Computers section
 
- Geek Code Generator v1.5 - Generates your geek code
- Copyright (C) 1999 Chris Gushue <seymour@iname.com>
+ Geek Code Generator v1.7 - Generates your geek code
+ Copyright (C) 1999-2000 Chris Gushue <seymour@lazygenes.net>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  at your option) any later version.
- 
+
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -29,7 +29,7 @@ int get_computers(void)
    do
      {
 	clearscreen();
-	printf("Computers                                                          Page 6 of 35\n");
+	printf("Computers                                                          Page %i of %i\n", PAGES-(PAGES-6), PAGES);
 	printf("===============================================================================\n");
         printf("1 C++++ I'll be the first in line to get the new cybernetic interface installed\n");
         printf("        into my skull.\n");
@@ -66,11 +66,11 @@ int get_computers(void)
 int get_unix_type(void)
 {
    int selection = 99;
-	
+
    do
      {
 	clearscreen();
-	printf("UNIX Type                                                         Page 7a of 35\n");
+	printf("UNIX Type                                                         Page %ia of %i\n", PAGES-(PAGES-7), PAGES);
 	printf("===============================================================================\n");
 	printf(" 1 B - BSD (use unless your BSDish system is mentioned below)\n");
 	printf(" 2 L - Linux\n");
@@ -130,7 +130,7 @@ int get_unix(int x)
    do
      {
 	clearscreen();
-	printf("UNIX                                                              Page 7b of 35\n");
+	printf("UNIX                                                              Page %ib of %i\n", PAGES-(PAGES-7), PAGES);
 	printf("===============================================================================\n");
         printf("1 U%s++++ I am the sysadmin. If you try and crack my machine don't be surprised\n", unix_type);
         printf("         if the municipal works department gets an \"accidental\" computer\n");
@@ -171,7 +171,7 @@ int get_perl(void)
    do
      {
 	clearscreen();
-	printf("Perl                                                               Page 8 of 35\n");
+	printf("Perl                                                               Page %i of %i\n", PAGES-(PAGES-8), PAGES);
 	printf("===============================================================================\n");
         printf(" 1 P+++++ I am Larry Wall, Tom Christiansen, or Randal Schwartz.\n");
         printf(" 2 P++++  I don't write Perl, I speak it. Perl has superseded all other\n");
@@ -212,7 +212,7 @@ int get_linux(void)
    do
      {
 	clearscreen();
-	printf("Linux                                                              Page 9 of 35\n");
+	printf("Linux                                                              Page %i of %i\n", PAGES-(PAGES-9), PAGES);
 	printf("===============================================================================\n");
         printf("1 L+++++ I am Linus, grovel before me.\n");
         printf("2 L++++  I am a Linux wizard. I munch C code for breakfast and have enough room\n");
@@ -253,7 +253,7 @@ int get_emacs(void)
    do
      {
 	clearscreen();
-	printf("Emacs                                                             Page 10 of 35\n");
+	printf("Emacs                                                             Page %i of %i\n", PAGES-(PAGES-10), PAGES);
 	printf("===============================================================================\n");
         printf("1 E+++  Emacs is my login shell! M-x doctor is my psychologist! I use Emacs to\n");
         printf("        control my TV and toaster oven! All you vi people don't know what you\n");
@@ -294,7 +294,7 @@ int get_www(void)
    do
      {
 	clearscreen();
-	printf("World Wide Web                                                    Page 11 of 35\n");
+	printf("World Wide Web                                                    Page %i of %i\n", PAGES-(PAGES-11), PAGES);
 	printf("===============================================================================\n");
         printf("1 W+++ I am a WebMaster. Don't even think about trying to view my page without\n");
         printf("       the latest version of Netscape. When I'm not on my normal net connection\n");
@@ -335,7 +335,7 @@ int get_usenet(void)
    do
      {
 	clearscreen();
-	printf("USENET News                                                       Page 12 of 35\n");
+	printf("USENET News                                                       Page %i of %i\n", PAGES-(PAGES-12), PAGES);
 	printf("===============================================================================\n");
         printf(" 1 N++++ I am Tim Pierce.\n");
         printf(" 2 N+++  I read so many newsgroups that the next batch of news comes in before\n");
@@ -376,7 +376,7 @@ int get_oracle(void)
    do
      {
 	clearscreen();
-	printf("USENET Oracle                                                     Page 13 of 35\n");
+	printf("USENET Oracle                                                     Page %i of %i\n", PAGES-(PAGES-13), PAGES);
 	printf("===============================================================================\n");
         printf("1 o+++++ I am Steve Kinzler.\n");
         printf("2 o++++  I am an active Priest.\n");
@@ -413,11 +413,11 @@ int get_oracle(void)
 int get_kibo(void)
 {
    int selection = 99;
-   
+
    do
      {
 	clearscreen();
-	printf("Kibo                                                              Page 14 of 35\n");
+	printf("Kibo                                                              Page %i of %i\n", PAGES-(PAGES-14), PAGES);
 	printf("===============================================================================\n");
         printf(" 1 K++++++ I am Kibo.\n");
         printf(" 2 K+++++  I've had sex with Kibo.\n");
@@ -458,7 +458,7 @@ int get_windows(void)
    do
      {
 	clearscreen();
-	printf("Microsoft Windows                                                 Page 15 of 35\n");
+	printf("Microsoft Windows                                                 Page %i of %i\n", PAGES-(PAGES-15), PAGES);
 	printf("===============================================================================\n");
         printf("1 w+++++ I am Bill Gates.\n");
         printf("2 w++++  I have Windows, Windows 95, Windows NT, and Windows MT Advanced Server\n");
@@ -499,7 +499,7 @@ int get_os2(void)
    do
      {
 	clearscreen();
-	printf("OS/2                                                              Page 16 of 35\n");
+	printf("OS/2                                                              Page %i of %i\n", PAGES-(PAGES-16), PAGES);
 	printf("===============================================================================\n");
         printf("1 O+++  I live, eat and breathe OS/2. All of my hard drives are HPFS.\n");
         printf("        I am the Anti-Gates.\n");
@@ -540,7 +540,7 @@ int get_mac(void)
    do
      {
 	clearscreen();
-	printf("Macintosh                                                         Page 17 of 35\n");
+	printf("Macintosh                                                         Page %i of %i\n", PAGES-(PAGES-17), PAGES);
 	printf("===============================================================================\n");
         printf("1 M++ I am a Mac guru. Anything those DOS putzes and Unix nerds can do, I can\n");
         printf("      do better, and if not, I'll write the damn software to do it.\n");
@@ -581,7 +581,7 @@ int get_vms(void)
    do
      {
 	clearscreen();
-	printf("VMS                                                               Page 18 of 35\n");
+	printf("VMS                                                               Page %i of %i\n", PAGES-(PAGES-18), PAGES);
 	printf("===============================================================================\n");
         printf("1 V+++ I am a VMS sysadmin. I wield far more power than those Unix admins,\n");
         printf("       because Unix can be found on any dweeb's desktop. Power through\n");
